==> haskell-concurrent-output-1.10.7-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.7
id: concurrent-output-1.10.7-LYUsNxM0C2UHNZEpaaNh29
key: concurrent-output-1.10.7-LYUsNxM0C2UHNZEpaaNh29
license: BSD-2-Clause
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
author: Joey Hess, Joachim Breitner
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
abi: 52c73a0785db178c9dcc068891094507
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
import-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-output-1.10.7
library-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-output-1.10.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/concurrent-output-1.10.7
hs-libraries: HSconcurrent-output-1.10.7-LYUsNxM0C2UHNZEpaaNh29
depends:
    ansi-terminal-0.8.1-9jw961s99VhJdcOClGpOKt
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 directory-1.3.3.0
    exceptions-0.10.0-4DJq1L1pYJ32FjrP4E9tSI process-1.6.3.0
    stm-2.5.0.0 terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY
    text-1.2.3.1 transformers-0.5.5.0 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.10.7-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.7
id: concurrent-output-1.10.7-5q2XjljoItQBGceSoG4Vpi
key: concurrent-output-1.10.7-5q2XjljoItQBGceSoG4Vpi
license: BSD-2-Clause
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
author: Joey Hess, Joachim Breitner
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
abi: 804ff66a1f59caa8c81c6bdca7f552be
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
import-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-output-1.10.7
library-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-output-1.10.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/concurrent-output-1.10.7
hs-libraries: HSconcurrent-output-1.10.7-5q2XjljoItQBGceSoG4Vpi
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 directory-1.3.3.0
    exceptions-0.10.0-6rXXyfyq3lH6yULL2y1jk1 process-1.6.3.0
    stm-2.5.0.0 terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY
    text-1.2.3.1 transformers-0.5.5.0 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
